/*
 * Jalview - A Sequence Alignment Editor and Viewer ($$Version-Rel$$)
 * Copyright (C) $$Year-Rel$$ The Jalview Authors
 * 
 * This file is part of Jalview.
 * 
 * Jalview is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation, either version 3
 * of the License, or (at your option) any later version.
 *  
 * Jalview is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty 
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 * PURPOSE.  See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Jalview.  If not, see <http://www.gnu.org/licenses/>.
 * The Jalview Authors are detailed in the 'AUTHORS' file.
 */
package jalview.gui;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertTrue;

import jalview.datamodel.Alignment;
import jalview.datamodel.AlignmentI;
import jalview.datamodel.Sequence;
import jalview.datamodel.SequenceI;

import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

public class SeqPanelTest
{
  AlignFrame af;

  @BeforeClass(alwaysRun = true)
  public void setUpJvOptionPane()
  {
    JvOptionPane.setInteractiveMode(false);
    JvOptionPane.setMockResponse(JvOptionPane.CANCEL_OPTION);
  }
  @Test(groups = "Functional")
  public void testSetStatusReturnsPosOrMinusOne()
  {
    SequenceI seq1 = new Sequence("Seq1", "AACDE");
    SequenceI seq2 = new Sequence("Seq2", "AA--E");
    AlignmentI al = new Alignment(new SequenceI[] { seq1, seq2 });
    AlignFrame alignFrame = new AlignFrame(al, al.getWidth(),
            al.getHeight());
    AlignmentI visAl = alignFrame.getViewport().getAlignment();
    // Test either side of gap
    // This first assert fails due to JAL-2563
    assertEquals(
            alignFrame.alignPanel.getSeqPanel().setStatusMessage(
                    visAl.getSequenceAt(1), 1, 1), 2);
    assertEquals(
            alignFrame.alignPanel.getSeqPanel().setStatusMessage(
                    visAl.getSequenceAt(1), 4, 1), 3);
    // Test gaps are -1
    assertEquals(
            alignFrame.alignPanel.getSeqPanel().setStatusMessage(
                    visAl.getSequenceAt(1), 2, 1), -1);
    assertEquals(
            alignFrame.alignPanel.getSeqPanel().setStatusMessage(
                    visAl.getSequenceAt(1), 3, 1), -1);
  }

  @Test(groups = "Functional")
  public void testAmbiguousAminoAcidGetsStatusMessage()
  {
    SequenceI seq1 = new Sequence("Seq1", "ABCDE");
    SequenceI seq2 = new Sequence("Seq2", "AB--E");
    AlignmentI al = new Alignment(new SequenceI[] { seq1, seq2 });
    AlignFrame alignFrame = new AlignFrame(al, al.getWidth(),
            al.getHeight());
    AlignmentI visAl = alignFrame.getViewport().getAlignment();
    // Test either side of gap
    // This first assert fails due to JAL-2563
    assertEquals(
            alignFrame.alignPanel.getSeqPanel().setStatusMessage(
                    visAl.getSequenceAt(1), 1, 1), 2);
    assertTrue(alignFrame.statusBar.getText().contains("(2)"));
  }
}
